package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaPoster;
import com.huiju.estateagents.service.TaPosterService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 分享海报表  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-09-21
 */
@RestController
@RequestMapping("/")
public class TaPosterController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPosterController.class);

    @Autowired
    public TaPosterService iPosterService;


    /**
     * 分页查询列表
     *
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/poster", method = RequestMethod.GET)
    public ResponseBean posterList(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                   @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaPoster> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPoster> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPoster> result = iPosterService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("posterList -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     *
     * @param poster 实体对象
     * @return
     */
    @RequestMapping(value = "/poster", method = RequestMethod.POST)
    public ResponseBean posterAdd(@RequestBody TaPoster poster) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iPosterService.save(poster)) {
                responseBean.addSuccess(poster);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("posterAdd -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     *
     * @param id 实体ID
     */
    @ResponseBody
    @RequestMapping(value = "/poster/{id}", method = RequestMethod.DELETE)
    public ResponseBean posterDelete(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iPosterService.removeById(id)) {
                responseBean.addSuccess("success");
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("posterDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     *
     * @param id     实体ID
     * @param poster 实体对象
     * @return
     */
    @RequestMapping(value = "/poster/{id}", method = RequestMethod.PUT)
    public ResponseBean posterUpdate(@PathVariable Integer id,
                                     @RequestBody TaPoster poster) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iPosterService.updateById(poster)) {
                responseBean.addSuccess(poster);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("posterUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     *
     * @param id 实体ID
     */
    @RequestMapping(value = "/poster/{id}", method = RequestMethod.GET)
    public ResponseBean posterGet(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iPosterService.getById(id));
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("posterDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
